@@ -10,7 +10,6 @@
 
 #include <CalendarSupport/CellItem>
 
-#include <Akonadi/ETMCalendar>
 #include <Akonadi/Item>
 
 #include <QDateTime>
@@ -75,35 +74,35 @@ public:
                QWidget *parent);
     ~AgendaItem() override;
 
-    Q_REQUIRED_RESULT int cellXLeft() const
+    [[nodiscard]] int cellXLeft() const
     {
         return mCellXLeft;
     }
 
-    Q_REQUIRED_RESULT int cellXRight() const
+    [[nodiscard]] int cellXRight() const
     {
         return mCellXRight;
     }
 
-    Q_REQUIRED_RESULT int cellYTop() const
+    [[nodiscard]] int cellYTop() const
     {
         return mCellYTop;
     }
 
-    Q_REQUIRED_RESULT int cellYBottom() const
+    [[nodiscard]] int cellYBottom() const
     {
         return mCellYBottom;
     }
 
-    Q_REQUIRED_RESULT int cellHeight() const;
-    Q_REQUIRED_RESULT int cellWidth() const;
+    [[nodiscard]] int cellHeight() const;
+    [[nodiscard]] int cellWidth() const;
 
-    Q_REQUIRED_RESULT int itemPos() const
+    [[nodiscard]] int itemPos() const
     {
         return mItemPos;
     }
 
-    Q_REQUIRED_RESULT int itemCount() const
+    [[nodiscard]] int itemCount() const
     {
         return mItemCount;
     }
@@ -140,7 +139,7 @@ public:
     void expandLeft(int dx);
     void expandRight(int dx);
 
-    Q_REQUIRED_RESULT bool isMultiItem() const;
+    [[nodiscard]] bool isMultiItem() const;
 
     AgendaItem::QPtr prevMoveItem() const
     {
@@ -185,7 +184,7 @@ public:
         return (mMultiItemInfo) ? (mMultiItemInfo->mLastMultiItem) : nullptr;
     }
 
-    Q_REQUIRED_RESULT bool dissociateFromMultiItem();
+    [[nodiscard]] bool dissociateFromMultiItem();
 
     void setIncidence(const KCalendarCore::Incidence::Ptr &incidence);
 
@@ -194,12 +193,12 @@ public:
         return mIncidence;
     }
 
-    Q_REQUIRED_RESULT QDateTime occurrenceDateTime() const
+    [[nodiscard]] QDateTime occurrenceDateTime() const
     {
         return mOccurrenceDateTime;
     }
 
-    Q_REQUIRED_RESULT QDate occurrenceDate() const;
+    [[nodiscard]] QDate occurrenceDate() const;
 
     // /** Update the date of this item's occurrence (not in the event) */
     void setOccurrenceDateTime(const QDateTime &qd);
@@ -209,7 +208,7 @@ public:
         mLabelText = text;
     }
 
-    Q_REQUIRED_RESULT QString text() const
+    [[nodiscard]] QString text() const
     {
         return mLabelText;
     }
@@ -228,7 +227,7 @@ public:
         mResourceColor = color;
     }
 
-    Q_REQUIRED_RESULT QColor resourceColor() const
+    [[nodiscard]] QColor resourceColor() const
     {
         return mResourceColor;
     }
@@ -267,11 +266,19 @@ private:
     // paint all visible icons
     void paintIcons(QPainter *p, int &x, int y, int ft);
 
-    void drawRoundedRect(QPainter *p, QRect rect, bool selected, const QColor &bgColor, const QColor &frameColor, bool frame, int ft, bool roundTop, bool roundBottom);
+    void drawRoundedRect(QPainter *p,
+                         QRect rect,
+                         bool selected,
+                         const QColor &bgColor,
+                         const QColor &frameColor,
+                         bool frame,
+                         int ft,
+                         bool roundTop,
+                         bool roundBottom);
 
-    Q_REQUIRED_RESULT QColor getCategoryColor() const;
-    Q_REQUIRED_RESULT QColor getFrameColor(const QColor &resourceColor, const QColor &categoryColor) const;
-    Q_REQUIRED_RESULT QColor getBackgroundColor(const QColor &resourceColor, const QColor &categoryColor) const;
+    [[nodiscard]] QColor getCategoryColor() const;
+    [[nodiscard]] QColor getFrameColor(const QColor &resourceColor, const QColor &categoryColor) const;
+    [[nodiscard]] QColor getBackgroundColor(const QColor &resourceColor, const QColor &categoryColor) const;
 
     int mCellXLeft, mCellXRight;
     int mCellYTop, mCellYBottom;
@@ -315,4 +322,3 @@ private:
     static QPixmap *completedPxmp;
 };
 }
-
