@@ -750,7 +750,7 @@ void TodoView::contextMenu(QPoint pos)
                 const bool actionIsRw = mItemPopupMenuReadWriteEntries.contains(entry);
 
                 const auto collection = Akonadi::EntityTreeModel::updatedCollection(model(), item.storageCollectionId());
-                const bool incidenceIsRO = collection.rights() & Akonadi::Collection::CanChangeItem;
+                const bool incidenceIsRO = (collection.rights() & Akonadi::Collection::CanChangeItem) == 0;
 
                 enable = hasItem && (!actionIsRw || !incidenceIsRO);
             }
