@@ -16,13 +16,18 @@
 #include "multiagenda/multiagendaview.h"
 #include "prefs.h"
 #include "timeline/timelineview.h"
-#include <CalendarSupport/CollectionSelection>
-
-#include <Akonadi/IncidenceChanger>
-#include <KCalendarCore/Event>
 
 #include <Akonadi/Collection>
+#include <Akonadi/CollectionFilterProxyModel>
 #include <Akonadi/ControlGui>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/IncidenceChanger>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/Monitor>
+
+#include <CalendarSupport/CollectionSelection>
+
+#include <KCalendarCore/Event>
 
 #include <KCheckableProxyModel>
 
@@ -33,9 +38,9 @@ using namespace EventViews;
 MainWindow::MainWindow(const QStringList &viewNames)
     : QMainWindow()
     , mViewNames(viewNames)
-    , mIncidenceChanger(0)
-    , mSettings(0)
-    , mViewPreferences(0)
+    , mIncidenceChanger(nullptr)
+    , mSettings(nullptr)
+    , mViewPreferences(nullptr)
 {
     mUi.setupUi(this);
     mUi.tabWidget->clear();
@@ -56,7 +61,7 @@ MainWindow::~MainWindow()
 
 void MainWindow::addView(const QString &viewName)
 {
-    EventView *eventView = 0;
+    EventView *eventView = nullptr;
 
     const auto start = QDateTime::currentDateTime().addDays(-1);
     const auto end = QDateTime::currentDateTime().addDays(1);
@@ -73,11 +78,17 @@ void MainWindow::addView(const QString &viewName)
 
     if (eventView) {
         eventView->setPreferences(*mViewPreferences);
-        eventView->setCalendar(mCalendar);
         eventView->setIncidenceChanger(mIncidenceChanger);
-        eventView->setDateRange(start, end);
         eventView->updateConfig();
+
+        for (const auto &calendar : mCalendars) {
+            eventView->addCalendar(calendar);
+        }
+
+        eventView->setDateRange(start, end);
+
         mUi.tabWidget->addTab(eventView, viewName);
+        mEventViews.push_back(eventView);
     } else {
         qCCritical(CALENDARVIEW_LOG) << "Cannot create view" << viewName;
     }
@@ -92,15 +103,37 @@ void MainWindow::delayedInit()
     // application settings
     mViewPreferences = new PrefsPtr(new Prefs(mSettings));
 
-    mCalendar = Akonadi::ETMCalendar::Ptr(new Akonadi::ETMCalendar());
-    KCheckableProxyModel *checkableProxy = mCalendar->checkableProxyModel();
-    QItemSelectionModel *selectionModel = checkableProxy->selectionModel();
+    mMonitor = new Akonadi::Monitor(this);
+    for (const auto &mt : KCalendarCore::Incidence::mimeTypes()) {
+        mMonitor->setMimeTypeMonitored(mt);
+    }
+    mMonitor->itemFetchScope().fetchFullPayload();
+    mMonitor->itemFetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
+    mEtm = new Akonadi::EntityTreeModel(mMonitor, this);
 
-    CalendarSupport::CollectionSelection *collectionSelection = new CalendarSupport::CollectionSelection(selectionModel);
+    auto collectionProxy = new Akonadi::CollectionFilterProxyModel(mEtm);
+    collectionProxy->addMimeTypeFilters(KCalendarCore::Incidence::mimeTypes());
+    collectionProxy->setSourceModel(mEtm);
+
+    auto selectionModel = new QItemSelectionModel(collectionProxy, mEtm);
+
+    auto checkableProxy = new KCheckableProxyModel(mEtm);
+    checkableProxy->setSourceModel(collectionProxy);
+    checkableProxy->setSelectionModel(selectionModel);
+
+    mUi.calendarView->setModel(checkableProxy);
+
+    CalendarSupport::CollectionSelection *collectionSelection = new CalendarSupport::CollectionSelection(selectionModel, this);
     EventViews::EventView::setGlobalCollectionSelection(collectionSelection);
 
+    connect(collectionSelection, &CalendarSupport::CollectionSelection::collectionSelected, this, &MainWindow::collectionSelected);
+    connect(collectionSelection, &CalendarSupport::CollectionSelection::collectionDeselected, this, &MainWindow::collectionDeselected);
+
+    for (const auto &collection : collectionSelection->selectedCollections()) {
+        collectionSelected(collection);
+    }
+
     mIncidenceChanger = new IncidenceChanger(this);
-    mCalendar->setCollectionFilteringEnabled(false);
 
     for (const QString &viewName : std::as_const(mViewNames)) {
         addView(viewName);
@@ -113,3 +146,37 @@ void MainWindow::addViewTriggered(QAction *action)
     viewName.remove(QLatin1Char('&'));
     addView(viewName);
 }
+
+void MainWindow::collectionSelected(const Akonadi::Collection &col)
+{
+    qDebug() << "Collection selected id=" << col.id() << "name=" << col.displayName();
+    auto calendar = Akonadi::CollectionCalendar::Ptr::create(mEtm, col);
+    mCalendars.push_back(calendar);
+
+    for (auto view : mEventViews) {
+        view->addCalendar(calendar);
+        view->updateView();
+    }
+}
+
+void MainWindow::collectionDeselected(const Akonadi::Collection &col)
+{
+    qDebug() << "Collection deselected id=" << col.id() << "name=" << col.displayName();
+    auto calendar = std::find_if(mCalendars.begin(), mCalendars.end(), [col](const auto &cal) {
+        return cal->collection() == col;
+    });
+    if (calendar == mCalendars.cend()) {
+        return;
+    }
+
+    const auto start = QDateTime::currentDateTime().addDays(-1);
+    const auto end = QDateTime::currentDateTime().addDays(1);
+
+    for (auto view : mEventViews) {
+        view->removeCalendar(*calendar);
+        view->updateView();
+    }
+
+    mCalendars.erase(calendar);
+}
+#include "moc_mainwindow.cpp"
